/**
 * @since 1.0.0
 */
import { DynamoDBClientConfig } from "@aws-sdk/client-dynamodb";
import { BatchExecuteStatementCommandInput, BatchExecuteStatementCommandOutput, BatchGetCommandInput, BatchGetCommandOutput, BatchWriteCommandInput, BatchWriteCommandOutput, DeleteCommandInput, DeleteCommandOutput, DynamoDBDocumentClient, ExecuteStatementCommandInput, ExecuteStatementCommandOutput, ExecuteTransactionCommandInput, ExecuteTransactionCommandOutput, GetCommandInput, GetCommandOutput, PutCommandInput, PutCommandOutput, QueryCommandInput, QueryCommandOutput, ScanCommandInput, ScanCommandOutput, TransactGetCommandInput, TransactGetCommandOutput, TransactWriteCommandInput, TransactWriteCommandOutput, TranslateConfig, UpdateCommandInput, UpdateCommandOutput } from "@aws-sdk/lib-dynamodb";
import { ConditionalCheckFailedError, DuplicateItemError, IdempotentParameterMismatchError, InternalServerError, InvalidEndpointError, ItemCollectionSizeLimitExceededError, ProvisionedThroughputExceededError, RequestLimitExceededError, ResourceNotFoundError, SdkError, TransactionCanceledError, TransactionConflictError, TransactionInProgressError } from "@effect-aws/client-dynamodb";
import { Effect, Layer } from "effect";
import { DynamoDBDocumentClientInstance } from "./DynamoDBDocumentClientInstance";
import { DynamoDBDocumentClientInstanceConfig } from "./DynamoDBDocumentClientInstanceConfig";
/**
 * @since 1.3.1
 */
export interface HttpHandlerOptions {
    /**
     * The maximum time in milliseconds that the connection phase of a request
     * may take before the connection attempt is abandoned.
     */
    requestTimeout?: number;
}
interface DynamoDBDocumentService$ {
    readonly _: unique symbol;
    /**
     * @see {@link BatchExecuteStatementCommand}
     */
    batchExecuteStatement(args: BatchExecuteStatementCommandInput, options?: HttpHandlerOptions): Effect.Effect<BatchExecuteStatementCommandOutput, SdkError | InternalServerError | RequestLimitExceededError>;
    /**
     * @see {@link BatchGetCommand}
     */
    batchGet(args: BatchGetCommandInput, options?: HttpHandlerOptions): Effect.Effect<BatchGetCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link BatchWriteCommand}
     */
    batchWrite(args: BatchWriteCommandInput, options?: HttpHandlerOptions): Effect.Effect<BatchWriteCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link DeleteCommand}
     */
    delete(args: DeleteCommandInput, options?: HttpHandlerOptions): Effect.Effect<DeleteCommandOutput, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link ExecuteStatementCommand}
     */
    executeStatement(args: ExecuteStatementCommandInput, options?: HttpHandlerOptions): Effect.Effect<ExecuteStatementCommandOutput, SdkError | ConditionalCheckFailedError | DuplicateItemError | InternalServerError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link ExecuteTransactionCommand}
     */
    executeTransaction(args: ExecuteTransactionCommandInput, options?: HttpHandlerOptions): Effect.Effect<ExecuteTransactionCommandOutput, SdkError | IdempotentParameterMismatchError | InternalServerError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError>;
    /**
     * @see {@link GetCommand}
     */
    get(args: GetCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link PutCommand}
     */
    put(args: PutCommandInput, options?: HttpHandlerOptions): Effect.Effect<PutCommandOutput, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link QueryCommand}
     */
    query(args: QueryCommandInput, options?: HttpHandlerOptions): Effect.Effect<QueryCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link ScanCommand}
     */
    scan(args: ScanCommandInput, options?: HttpHandlerOptions): Effect.Effect<ScanCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link TransactGetCommand}
     */
    transactGet(args: TransactGetCommandInput, options?: HttpHandlerOptions): Effect.Effect<TransactGetCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError>;
    /**
     * @see {@link TransactWriteCommand}
     */
    transactWrite(args: TransactWriteCommandInput, options?: HttpHandlerOptions): Effect.Effect<TransactWriteCommandOutput, SdkError | IdempotentParameterMismatchError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError>;
    /**
     * @see {@link UpdateCommand}
     */
    update(args: UpdateCommandInput, options?: HttpHandlerOptions): Effect.Effect<UpdateCommandOutput, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
}
/**
 * @since 1.0.0
 * @category constructors
 */
export declare const makeDynamoDBDocumentService: Effect.Effect<DynamoDBDocumentService$, never, DynamoDBDocumentClientInstance>;
declare const DynamoDBDocumentService_base: import("effect/Context").TagClass<DynamoDBDocumentService, "@effect-aws/lib-dynamodb/DynamoDBDocumentService", DynamoDBDocumentService$> & {
    readonly _: Effect.Effect<DynamoDBDocumentService$["_"], never, DynamoDBDocumentService>;
    batchExecuteStatement: (args: BatchExecuteStatementCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<BatchExecuteStatementCommandOutput, InternalServerError | RequestLimitExceededError | SdkError, DynamoDBDocumentService>;
    batchGet: (args: BatchGetCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<BatchGetCommandOutput, InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | SdkError, DynamoDBDocumentService>;
    batchWrite: (args: BatchWriteCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<BatchWriteCommandOutput, InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | SdkError, DynamoDBDocumentService>;
    delete: (args: DeleteCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<DeleteCommandOutput, ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError | SdkError, DynamoDBDocumentService>;
    executeStatement: (args: ExecuteStatementCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<ExecuteStatementCommandOutput, ConditionalCheckFailedError | DuplicateItemError | InternalServerError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError | SdkError, DynamoDBDocumentService>;
    executeTransaction: (args: ExecuteTransactionCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<ExecuteTransactionCommandOutput, IdempotentParameterMismatchError | InternalServerError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError | SdkError, DynamoDBDocumentService>;
    get: (args: GetCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<GetCommandOutput, InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | SdkError, DynamoDBDocumentService>;
    put: (args: PutCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<PutCommandOutput, ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError | SdkError, DynamoDBDocumentService>;
    query: (args: QueryCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<QueryCommandOutput, InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | SdkError, DynamoDBDocumentService>;
    scan: (args: ScanCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<ScanCommandOutput, InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | SdkError, DynamoDBDocumentService>;
    transactGet: (args: TransactGetCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<TransactGetCommandOutput, InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | SdkError, DynamoDBDocumentService>;
    transactWrite: (args: TransactWriteCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<TransactWriteCommandOutput, IdempotentParameterMismatchError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError | SdkError, DynamoDBDocumentService>;
    update: (args: UpdateCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<UpdateCommandOutput, ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError | SdkError, DynamoDBDocumentService>;
} & {
    use: <X>(body: (_: DynamoDBDocumentService$) => X) => X extends Effect.Effect<infer A, infer E, infer R> ? Effect.Effect<A, E, R | DynamoDBDocumentService> : Effect.Effect<X, never, DynamoDBDocumentService>;
};
/**
 * @since 1.0.0
 * @category models
 */
export declare class DynamoDBDocumentService extends DynamoDBDocumentService_base {
    static readonly defaultLayer: Layer.Layer<DynamoDBDocumentService, never, never>;
    static readonly layer: (config: TranslateConfig) => Layer.Layer<DynamoDBDocumentService, never, never>;
    static readonly baseLayer: (evaluate: (defaultConfig: DynamoDBClientConfig) => DynamoDBDocumentClient) => Layer.Layer<DynamoDBDocumentService, never, never>;
}
/**
 * @since 1.0.0
 * @category models
 * @alias DynamoDBDocumentService
 */
export declare const DynamoDBDocument: typeof DynamoDBDocumentService;
/**
 * @since 1.0.0
 * @category layers
 * @deprecated use DynamoDBDocument.baseLayer instead
 */
export declare const BaseDynamoDBDocumentServiceLayer: Layer.Layer<DynamoDBDocumentService, never, DynamoDBDocumentClientInstance>;
/**
 * @since 1.0.0
 * @category layers
 * @deprecated use DynamoDBDocument.layer instead
 */
export declare const DynamoDBDocumentServiceLayer: Layer.Layer<DynamoDBDocumentService, never, DynamoDBDocumentClientInstanceConfig>;
/**
 * @since 1.0.0
 * @category layers
 * @deprecated use DynamoDBDocument.defaultLayer instead
 */
export declare const DefaultDynamoDBDocumentServiceLayer: Layer.Layer<DynamoDBDocumentService, never, never>;
export {};
